@@ -413,6 +413,8 @@ def test_error_when_no_deployed_record(runner, mock_cli_factory):
                     reason="Cannot generate pipeline for python3.7.")
 @pytest.mark.skipif(sys.version_info[:2] == (3, 8),
                     reason="Cannot generate pipeline for python3.8.")
+@pytest.mark.skipif(sys.version_info[:2] == (3, 9),
+                    reason="Cannot generate pipeline for python3.9.")
 def test_can_generate_pipeline_for_all(runner):
     with runner.isolated_filesystem():
         newproj.create_new_project_skeleton('testproject')
